@@ -13,7 +13,7 @@ class RemoteControlApp:
         app = Flask(__name__)
         app.add_url_rule('/', view_func=RemoteControlApp.index, methods=['GET'])
         app.add_url_rule('/accept_certificate', view_func=RemoteControlApp.accept_certificate, methods=['GET'])
-        app.add_url_rule('/linux_test', view_func=RemoteControlApp.test_script_folder, methods=['GET'])
+        app.add_url_rule('/folder_test', view_func=RemoteControlApp.test_script_folder, methods=['GET'])
         # app.register_error_handler(404, RemoteControlApp.page_not_found)
         logging.getLogger('werkzeug').disabled = True
         debug_mode = True
